@@ -1166,7 +1166,7 @@ class Askdata(SignUp):
             })
         return pd.DataFrame(data=columns)
 
-    def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50):
+    def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50, offset=0):
 
         if (workspace == ''):
             if ('/' in dataset):
@@ -1175,7 +1175,7 @@ class Askdata(SignUp):
 
 
         agent = self.agent(slug=workspace)
-        return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit)
+        return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit, offset=offset)
 
 
     def get(self, query, workspace='', dataset='', lang="en", fields:list=[], filters=None, sorted_by=None, get_raw_data=False):
